import mfire.utils.mfxarray as xr
from mfire import Datetime
from mfire.production.base import BaseCDPComponent
from mfire.production.periods import CDPPeriod
from tests.composite.factories import (
    RiskComponentCompositeFactory,
    TextComponentCompositeFactory,
)


class TestBaseCDPComponent:
    def test_from_composite(self):
        ds = xr.Dataset(
            {"A": (["id"], [1])},
            coords={"id": ["geo_id"], "areaName": (["id"], ["area_1_name"])},
        )

        # Test with TextComponentComposite
        compo = TextComponentCompositeFactory(data=ds)
        base_compo = BaseCDPComponent.from_composite(compo, geo_id="geo_id")

        assert base_compo.ComponentId == "text_component_id"
        assert base_compo.ComponentName == "text_component_name"
        assert base_compo.Period == CDPPeriod(
            PeriodId="period_id",
            PeriodName="period_name",
            DateDebutPeriode=Datetime(2023, 3, 1),
            DateFinPeriode=Datetime(2023, 3, 5),
        )
        assert base_compo.GeoId == "geo_id"
        assert base_compo.GeoName == "area_1_name"

        # Test with RiskComponentComposite
        compo = RiskComponentCompositeFactory()
        base_compo = BaseCDPComponent.from_composite(compo, geo_id="geo_id")

        assert base_compo.ComponentId == "risk_component_id"
        assert base_compo.ComponentName == "risk_component_name"
        assert base_compo.Period == CDPPeriod(
            PeriodId="period_id",
            PeriodName="period_name",
            DateDebutPeriode=Datetime(2023, 3, 1),
            DateFinPeriode=Datetime(2023, 3, 5),
        )
        assert base_compo.GeoId == "geo_id"
        assert base_compo.GeoName == "N.A"

        compo = RiskComponentCompositeFactory(risk_ds=ds)
        base_compo = BaseCDPComponent.from_composite(compo, geo_id="geo_id")
        assert base_compo.GeoName == "area_1_name"
